@@ -9,7 +9,16 @@ from django.forms import (
     RadioSelect,
     Select,
 )
-from django.forms.widgets import FileInput, Input, Textarea
+from django.forms.widgets import (
+    EmailInput,
+    Input,
+    NumberInput,
+    PasswordInput,
+    SelectMultiple,
+    Textarea,
+    TextInput,
+    URLInput,
+)
 from django.utils.html import conditional_escape, format_html, strip_tags
 from django.utils.safestring import mark_safe
 
@@ -260,7 +269,7 @@ class FieldRenderer(BaseRenderer):
 
     @property
     def is_floating(self):
-        return super().is_floating and self.can_widget_float(self.widget) and self.is_widget_form_control(self.widget)
+        return super().is_floating and self.can_widget_float(self.widget)
 
     @property
     def default_placeholder(self):
@@ -270,24 +279,19 @@ class FieldRenderer(BaseRenderer):
     def restore_widget_attrs(self):
         self.widget.attrs = self.initial_attrs.copy()
 
-    def is_widget_form_control(self, widget):
-        """Return whether given widget is of type `form-control`."""
-        return (isinstance(widget, Input) and not isinstance(widget, CheckboxInput)) or isinstance(widget, Textarea)
-
     def get_widget_input_type(self, widget):
         """Return input type of widget, or None."""
         return widget.input_type if isinstance(widget, Input) else None
 
     def can_widget_float(self, widget):
         """Return whether given widget can be set to `form-floating` behavior."""
-        # TODO: Add support for select widgets, within Bootstrap 5 restrictions
-        # TODO: Add support for textarea widgets
-        # TODO: Check support for date, time and other types
-        return (
-            not isinstance(widget, FileInput)
-            and self.is_widget_form_control(widget)
-            and self.get_widget_input_type(widget) != "color"
-        )
+        if isinstance(widget, (TextInput, NumberInput, EmailInput, URLInput, PasswordInput)):
+            return self.get_widget_input_type(widget) in ["text", "number", "email", "url", "password"]
+        if isinstance(widget, Textarea):
+            return True
+        if isinstance(widget, Select):
+            return self.size == DEFAULT_SIZE and not isinstance(widget, (SelectMultiple, RadioSelect))
+        return False
 
     def add_widget_class_attrs(self, widget=None):
         """Add class attribute to widget."""
@@ -297,18 +301,23 @@ class FieldRenderer(BaseRenderer):
 
         before = []
         classes = [widget.attrs.get("class", "")]
+
         if ReadOnlyPasswordHashWidget is not None and isinstance(widget, ReadOnlyPasswordHashWidget):
             before.append("form-control-static")
-        elif self.is_widget_form_control(widget):
-            before.append("form-control")
-            if self.get_widget_input_type(widget) == "color":
-                before.append("form-control-color")
-            size_prefix = "form-control"
         elif isinstance(widget, Select):
             before.append("form-select")
             size_prefix = "form-select"
         elif isinstance(widget, CheckboxInput):
             before.append("form-check-input")
+        elif isinstance(widget, (Input, Textarea)):
+            input_type = self.get_widget_input_type(widget)
+            if input_type == "range":
+                before.append("form-range")
+            else:
+                before.append("form-control")
+                if input_type == "color":
+                    before.append("form-control-color")
+                size_prefix = "form-control"
 
         if size_prefix:
             classes.append(get_size_class(self.size, prefix=size_prefix, skip=["xs", "md"]))
@@ -425,20 +434,25 @@ class FieldRenderer(BaseRenderer):
     def get_wrapper_classes(self):
         """Return classes for wrapper."""
         wrapper_classes = [self.wrapper_class]
+
         if self.is_floating:
             wrapper_classes.append("form-floating")
+
         if self.field.errors:
             wrapper_classes.append(self.error_css_class)
         elif self.field.form.is_bound:
             wrapper_classes.append(self.success_css_class)
+
         if self.field.field.required:
             wrapper_classes.append(self.required_css_class)
+
         if self.is_inline:
             wrapper_classes.append(self.get_inline_field_class())
         else:
             if self.is_horizontal:
                 wrapper_classes.append("row")
             wrapper_classes.append("mb-3")
+
         return merge_css_classes(*wrapper_classes)
 
     def field_before_label(self):
